# Mocha


---

## Directory Structure

    - serve.py
    |
    |-- /app
        |
        |-- config.py
        |
        |-- models.py  
        |
        |-- helpers.py
        |
        |-- cli.py
        |
        |-- views/
            |
            |-- main.py
        |
        |-- templates/
            |
            |-- layouts/
                |
                |-- base.jade
                |
            |-- main/
                |
                |-- Index/
                    |
                    |-- index.jade
        |
        |-- /static/
        |
        |-- /var/

---

## Serve your app

    mocha :serve

